# coding: utf-8
#
# COPYRIGHT (C) 1991 - 2015  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.

import os
import os.path as osp
import re


# repIni is required to find editeur.ini
repIni = osp.dirname(osp.abspath(__file__))

# lang is the field used to show the help strings : fr or ang
lang = 'fr'

# string encoding of the cata.py (default is 'ascii')
encoding = 'utf-8'

# User/Developer
isdeveloppeur = "NON"

# list of catalogues (commands syntax description)
catalogues = (
#CATALOG_MARKER
)

# path to the program used to open the documents
exec_acrobat = "/usr/bin/firefox"


def getVersionNumber( installdir, level=2 ):
    """Return the number of the Code_Aster version installed in `installdir`"""
    pkg = osp.join( installdir, 'lib', 'aster', 'aster_pkginfo.py' )
    ctxt = {}
    execfile( pkg, ctxt )
    info = ctxt.get('version_info')
    if not info:
        return ()
    return [str(i) for i in info.version[:level]]

def addCatalog(catalogName, catalogPath, default=False):
    """This function helps you to add a new catalog dynamically"""
    global catalogues
    item = ['ASTER', catalogName, catalogPath, 'python']
    if default:
        item.append('defaut')
    catalogues += (tuple(item), )

def setEficasVars( context, name, default=False, level=2 ):
    """Define variables for eficas in the given context
    The line(s) are also added to the 'catalogues' list.
    Variables are:
        rep_doc_`name`: path to the file with documentation hyperlinks
        rep_doc_`number`: idem
        rep_mat_`name`: deprecated, just to avoid a warning
        rep_mat_`number`: idem
        + lines added to catalogues
    """
    nameVar = re.sub("[\-\. ]", "_", name)
    installdir = os.environ.get("ASTER_" + nameVar.upper())
    if not installdir:
        return
    vers = getVersionNumber( installdir, level=level )
    # ex. rep_doc_stable = ...
    context['rep_doc_' + nameVar] = osp.join(repIni, 'Doc', 'clefs_docu_' + nameVar)
    context['rep_mat_' + nameVar] = ''
    cata = context['catalogues']
    cataPath = osp.join(installdir, 'lib', 'aster', 'Cata', 'cata.py')
    addCatalog( name, cataPath, default=default )
    # with version number
    if vers:
        versVar = ''.join(vers)     # ex. 124
        versStr = '.'.join(vers)    # ex. 12.4
        # ex. rep_doc_124 = ...
        context['rep_doc_' + versVar] = context['rep_doc_' + nameVar]
        context['rep_mat_' + versVar] = context['rep_mat_' + nameVar]
        addCatalog( versStr, cataPath )

# add variables in the global context if the environment variables are defined
setEficasVars( globals(), "oldstable" )
setEficasVars( globals(), "stable", default=True )
setEficasVars( globals(), "testing" )
setEficasVars( globals(), "stable-updates", level=3 )
setEficasVars( globals(), "unstable", level=3 )


# to avoid deprecation messages
mode_nouv_commande = 'alpha'

# cleanup
del getVersionNumber
del addCatalog
del setEficasVars
